@@ -1,6 +1,6 @@
 #' Map `lenghtMenu` property
 #'
-#' @description `r lifecycle::badge("stable")`\cr
+#' @description
 #' Maps the `lengthMenu` selected value property of `DT::datatable` to a `shiny` variable.
 #' @param dt_name `ns()` of `inputId` of the `DT::datatable`
 #' @param dt_rows `ns()` of `inputId` of the variable that holds the current selected value of `lengthMenu`
@@ -16,23 +16,23 @@
 #' ui <- function(id) {
 #'   ns <- NS(id)
 #'   tagList(
-#'     DTOutput(ns("data_table")),
-#'     get_dt_rows(ns("data_table"), ns("dt_rows"))
+#'     get_dt_rows(ns("data_table"), ns("dt_rows")),
+#'     textOutput(ns("rows")),
+#'     DT::DTOutput(ns("data_table"))
 #'   )
 #' }
 #'
 #' # use the input$dt_rows in the Shiny Server function
 #' server <- function(id) {
 #'   moduleServer(id, function(input, output, session) {
-#'     output$data_table <- renderDataTable(
-#'       {
-#'         iris
-#'       },
-#'       options = list(pageLength = input$dt_rows)
-#'     )
+#'     output$data_table <- DT::renderDataTable(iris)
+#'     # Change rows selected to see the first line on the UI change
+#'     rows <- reactive({
+#'       paste0("Selected Rows ", input$dt_rows)
+#'     })
+#'     output$rows <- renderText(rows())
 #'   })
 #' }
-#'
 #' if (interactive()) {
 #'   shinyApp(
 #'     ui = ui("my_table_module"),
@@ -46,7 +46,7 @@ get_dt_rows <- function(dt_name, dt_rows) {
       sprintf(
         "$(document).ready(function() {
         $('%s').on('length.dt', function(e, settings, len) {
-        Shiny.onInputChange('%s', len);
+        Shiny.setInputValue('%s', len);
         });
         });",
         paste0("#", dt_name),
